@@ -17,7 +17,8 @@ pub trait DataProvider {
         fields_names: &[String],
         titles: &[String],
         fields_values: &[Box<dyn Expression>],
-    ) -> GitQLObject;
+        hidden_count: i64,
+    ) -> Result<GitQLObject, String>;
 }
 
 pub fn select_values(
