@@ -2,6 +2,8 @@ use std::collections::HashMap;
 
 use gitql_ast::statement::AggregateValue;
 
+use crate::tokenizer::Location;
+
 #[derive(Default)]
 pub struct ParserContext {
     pub aggregations: HashMap<String, AggregateValue>,
@@ -9,6 +11,13 @@ pub struct ParserContext {
     pub selected_fields: Vec<String>,
     pub hidden_selections: Vec<String>,
 
+    pub table_name: String,
+    pub projection_names: Vec<String>,
+    pub projection_locations: Vec<Location>,
+
+    pub name_alias_table: HashMap<String, String>,
+
+    pub has_select_statement: bool,
     pub generated_field_count: i32,
     pub is_single_value_query: bool,
     pub has_group_by_statement: bool,
