@@ -27,9 +27,11 @@ use crate::tokenizer::TokenKind;
 use crate::type_checker::are_types_equals;
 use crate::type_checker::check_all_values_are_same_type;
 use crate::type_checker::check_function_call_arguments;
+use crate::type_checker::is_expression_type_equals;
 use crate::type_checker::resolve_call_expression_return_type;
 use crate::type_checker::type_check_projection_symbols;
 use crate::type_checker::type_check_selected_fields;
+use crate::type_checker::ExprTypeCheckResult;
 use crate::type_checker::TypeCheckResult;
 
 pub fn parse_gql(tokens: Vec<Token>, env: &mut Environment) -> Result<Query, Box<Diagnostic>> {
@@ -40,7 +42,7 @@ pub fn parse_gql(tokens: Vec<Token>, env: &mut Environment) -> Result<Query, Box
         TokenKind::Set => parse_set_query(env, &tokens, &mut position),
         TokenKind::Select => parse_select_query(env, &tokens, &mut position),
         TokenKind::Describe => parse_describe_query(env, &tokens, &mut position),
-        TokenKind::Show => parse_show_query(env, &tokens, &mut position),
+        TokenKind::Show => parse_show_query(&tokens, &mut position),
         _ => Err(un_expected_statement_error(&tokens, &mut position)),
     };
 
@@ -51,7 +53,7 @@ pub fn parse_gql(tokens: Vec<Token>, env: &mut Environment) -> Result<Query, Box
         }
     }
 
-    // Check for un expected content after valid statement
+    // Check for unexpected content after valid statement
     if query_result.is_ok() && position < tokens.len() {
         return Err(un_expected_content_after_correct_statement(
             &first_token.literal,
@@ -141,35 +143,43 @@ fn parse_set_query(
 }
 
 fn parse_describe_query(
-    _: &mut Environment,
+    env: &mut Environment,
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Query, Box<Diagnostic>> {
-    let len = tokens.len();
-
-    // Consume Set keyword
+    // Consume `DESCRIBE` keyword
     *position += 1;
 
-    if *position >= len || tokens[*position].kind != TokenKind::Symbol {
-        return Err(Diagnostic::error("Expect table name after DESC Statement")
-            .with_location(get_safe_location(tokens, *position - 1))
-            .as_boxed());
+    if *position >= tokens.len() || tokens[*position].kind != TokenKind::Symbol {
+        return Err(
+            Diagnostic::error("Expect table name after DESCRIBE Statement")
+                .with_location(get_safe_location(tokens, *position))
+                .as_boxed(),
+        );
     }
 
-    let name = &tokens[*position].literal;
+    // Make sure table name is valid
+    let table_name = tokens[*position].literal.to_string();
+    if !env
+        .schema
+        .tables_fields_names
+        .contains_key(table_name.as_str())
+    {
+        return Err(
+            Diagnostic::error(&format!("Unresolved table name `{}`", table_name))
+                .add_help("You can use the command `SHOW TABLES` to get list of current tables")
+                .with_location(get_safe_location(tokens, *position))
+                .as_boxed(),
+        );
+    }
 
+    // Consume Table Name
     *position += 1;
 
-    Ok(Query::Describe(DescribeStatement {
-        table_name: name.to_string(),
-    }))
+    Ok(Query::Describe(DescribeStatement { table_name }))
 }
 
-fn parse_show_query(
-    _: &mut Environment,
-    tokens: &[Token],
-    position: &mut usize,
-) -> Result<Query, Box<Diagnostic>> {
+fn parse_show_query(tokens: &[Token], position: &mut usize) -> Result<Query, Box<Diagnostic>> {
     // Consume SHOW keyword
     *position += 1;
 
@@ -413,13 +423,8 @@ fn parse_select_statement(
     let mut fields_names: Vec<String> = Vec::new();
     let mut fields_values: Vec<Box<dyn Expression>> = Vec::new();
     let mut is_select_all = false;
-    let mut is_distinct = false;
 
-    // Check if select has distinct keyword after it
-    if tokens[*position].kind == TokenKind::Distinct {
-        is_distinct = true;
-        *position += 1;
-    }
+    let distinct = parse_select_distinct_option(context, tokens, position)?;
 
     // Select all option
     if *position < tokens.len() && tokens[*position].kind == TokenKind::Star {
@@ -430,9 +435,8 @@ fn parse_select_statement(
         while *position < tokens.len() && tokens[*position].kind != TokenKind::From {
             let expression = parse_expression(context, env, tokens, position)?;
             let expr_type = expression.expr_type(env).clone();
-            let expression_name = get_expression_name(&expression);
-            let field_name = if expression_name.is_ok() {
-                expression_name.ok().unwrap()
+            let field_name = if let Some(expression_literal) = expression_literal(&expression) {
+                expression_literal
             } else {
                 context.generate_column_name()
             };
@@ -566,10 +570,93 @@ fn parse_select_statement(
         table_name: table_name.to_string(),
         fields_names,
         fields_values,
-        is_distinct,
+        distinct,
     }))
 }
 
+fn parse_select_distinct_option(
+    context: &mut ParserContext,
+    tokens: &[Token],
+    position: &mut usize,
+) -> Result<Distinct, Box<Diagnostic>> {
+    if tokens[*position].kind == TokenKind::Distinct {
+        // Consume `DISTINCT` keyword
+        *position += 1;
+
+        if *position < tokens.len() && tokens[*position].kind == TokenKind::On {
+            // Consume `ON` keyword
+            *position += 1;
+
+            if *position >= tokens.len() || tokens[*position].kind != TokenKind::LeftParen {
+                return Err(Diagnostic::error("Expect `(` after `DISTINCT ON`")
+                    .add_help("Try to add `(` after ON and before fields")
+                    .with_location(get_safe_location(tokens, *position))
+                    .as_boxed());
+            }
+
+            // Consume `(` Left Parenthesis
+            *position += 1;
+
+            let mut distinct_fields: Vec<String> = vec![];
+            while *position < tokens.len() && tokens[*position].kind != TokenKind::RightParen {
+                let field_token = &tokens[*position];
+                let literal = &field_token.literal;
+                let location = field_token.location;
+
+                distinct_fields.push(literal.to_string());
+
+                context.hidden_selections.push(literal.to_string());
+                context.projection_names.push(literal.to_string());
+                context.projection_locations.push(location);
+
+                // Consume field name
+                *position += 1;
+
+                if *position < tokens.len() && tokens[*position].kind == TokenKind::Comma {
+                    *position += 1;
+                } else {
+                    break;
+                }
+            }
+
+            if *position >= tokens.len() || tokens[*position].kind != TokenKind::RightParen {
+                return Err(Diagnostic::error("Expect `)` after `DISTINCT ON fields`")
+                    .add_help("Try to add `)` after fields")
+                    .with_location(get_safe_location(tokens, *position))
+                    .as_boxed());
+            }
+
+            // Consume `)` Right Parenthesis
+            *position += 1;
+
+            // Prevent passing empty fields
+            if distinct_fields.is_empty() {
+                return Err(Diagnostic::error(
+                    "DISTINCT ON(...) must be used with one of more column",
+                )
+                .add_help("Try to add one or more columns from current table")
+                .with_location(get_safe_location(tokens, *position))
+                .as_boxed());
+            }
+
+            // Prevent user from writing comma after DISTINCT ON
+            if *position < tokens.len() && tokens[*position].kind == TokenKind::Comma {
+                return Err(
+                    Diagnostic::error("No need to add Comma `,` after DISTINCT ON")
+                        .add_help("Try to remove `,` after DISTINCT ON fields")
+                        .with_location(get_safe_location(tokens, *position))
+                        .as_boxed(),
+                );
+            }
+
+            return Ok(Distinct::DistinctOn(distinct_fields));
+        }
+        return Ok(Distinct::DistinctAll);
+    }
+
+    Ok(Distinct::None)
+}
+
 fn parse_where_statement(
     context: &mut ParserContext,
     env: &mut Environment,
@@ -587,19 +674,27 @@ fn parse_where_statement(
 
     let aggregations_count_before = context.aggregations.len();
 
-    // Make sure WHERE condition expression has boolean type
+    // Make sure WHERE condition expression has boolean type or can implicit casted to boolean
     let condition_location = tokens[*position].location;
-    let condition = parse_expression(context, env, tokens, position)?;
-    let condition_type = condition.expr_type(env);
-    if condition_type != DataType::Boolean {
-        return Err(Diagnostic::error(&format!(
-            "Expect `WHERE` condition to be type {} but got {}",
-            DataType::Boolean,
-            condition_type
-        ))
-        .add_note("`WHERE` statement condition must be Boolean")
-        .with_location(condition_location)
-        .as_boxed());
+    let mut condition = parse_expression(context, env, tokens, position)?;
+    match is_expression_type_equals(env, &condition, &DataType::Boolean) {
+        ExprTypeCheckResult::ImplicitCasted(expr) => {
+            condition = expr;
+        }
+        ExprTypeCheckResult::Error(diagnostic) => {
+            return Err(diagnostic);
+        }
+        ExprTypeCheckResult::NotEqualAndCantImplicitCast => {
+            return Err(Diagnostic::error(&format!(
+                "Expect `WHERE` condition to be type {} but got {}",
+                DataType::Boolean,
+                condition.expr_type(env)
+            ))
+            .add_note("`WHERE` statement condition must be Boolean")
+            .with_location(condition_location)
+            .as_boxed());
+        }
+        _ => {}
     }
 
     let aggregations_count_after = context.aggregations.len();
@@ -622,7 +717,9 @@ fn parse_group_by_statement(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Box<dyn Statement>, Box<Diagnostic>> {
+    // Consume `Group` keyword
     *position += 1;
+
     if *position >= tokens.len() || tokens[*position].kind != TokenKind::By {
         return Err(
             Diagnostic::error("Expect keyword `by` after keyword `group`")
@@ -631,31 +728,26 @@ fn parse_group_by_statement(
                 .as_boxed(),
         );
     }
-    *position += 1;
-    if *position >= tokens.len() || tokens[*position].kind != TokenKind::Symbol {
-        return Err(Diagnostic::error("Expect field name after `group by`")
-            .with_location(get_safe_location(tokens, *position - 1))
-            .as_boxed());
-    }
-
-    let field_name = tokens[*position].literal.to_string();
-    if !context.selected_fields.contains(&field_name) {
-        context.hidden_selections.push(field_name.to_string());
-    }
 
+    // Consume `By` keyword
     *position += 1;
 
-    if !env.contains(&field_name) {
-        return Err(
-            Diagnostic::error("Current table not contains field with this name")
-                .add_help("Check the documentations to see available fields for each tables")
-                .with_location(get_safe_location(tokens, *position - 1))
-                .as_boxed(),
-        );
+    // Parse one or more expression
+    let mut values: Vec<Box<dyn Expression>> = vec![];
+    while *position < tokens.len() {
+        values.push(parse_expression(context, env, tokens, position)?);
+
+        if *position < tokens.len() && tokens[*position].kind == TokenKind::Comma {
+            // Consume Comma `,`
+            *position += 1;
+            continue;
+        }
+
+        break;
     }
 
     context.has_group_by_statement = true;
-    Ok(Box::new(GroupByStatement { field_name }))
+    Ok(Box::new(GroupByStatement { values }))
 }
 
 fn parse_having_statement(
@@ -677,17 +769,25 @@ fn parse_having_statement(
 
     // Make sure HAVING condition expression has boolean type
     let condition_location = tokens[*position].location;
-    let condition = parse_expression(context, env, tokens, position)?;
-    let condition_type = condition.expr_type(env);
-    if condition_type != DataType::Boolean {
-        return Err(Diagnostic::error(&format!(
-            "Expect `HAVING` condition to be type {} but got {}",
-            DataType::Boolean,
-            condition_type
-        ))
-        .add_note("`HAVING` statement condition must be Boolean")
-        .with_location(condition_location)
-        .as_boxed());
+    let mut condition = parse_expression(context, env, tokens, position)?;
+    match is_expression_type_equals(env, &condition, &DataType::Boolean) {
+        ExprTypeCheckResult::ImplicitCasted(expr) => {
+            condition = expr;
+        }
+        ExprTypeCheckResult::Error(diagnostic) => {
+            return Err(diagnostic);
+        }
+        ExprTypeCheckResult::NotEqualAndCantImplicitCast => {
+            return Err(Diagnostic::error(&format!(
+                "Expect `HAVING` condition to be type {} but got {}",
+                DataType::Boolean,
+                condition.expr_type(env)
+            ))
+            .add_note("`HAVING` statement condition must be Boolean")
+            .with_location(condition_location)
+            .as_boxed());
+        }
+        _ => {}
     }
 
     Ok(Box::new(HavingStatement { condition }))
@@ -1072,7 +1172,6 @@ fn parse_between_expression(
     position: &mut usize,
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
     let expression = parse_logical_or_expression(context, env, tokens, position)?;
-
     if *position < tokens.len() && tokens[*position].kind == TokenKind::Between {
         let between_location = tokens[*position].location;
 
@@ -1130,32 +1229,39 @@ fn parse_logical_or_expression(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
-    let expression = parse_logical_and_expression(context, env, tokens, position);
-    if expression.is_err() || *position >= tokens.len() {
-        return expression;
-    }
-
-    let mut lhs = expression.ok().unwrap();
+    let mut lhs = parse_logical_and_expression(context, env, tokens, position)?;
     while *position < tokens.len() && tokens[*position].kind == TokenKind::LogicalOr {
-        *position += 1;
-
-        if lhs.expr_type(env) != DataType::Boolean {
-            return Err(type_mismatch_error(
-                tokens[*position - 2].location,
-                DataType::Boolean,
-                lhs.expr_type(env),
-            )
-            .as_boxed());
+        let expected_type = DataType::Boolean;
+        match is_expression_type_equals(env, &lhs, &expected_type) {
+            ExprTypeCheckResult::ImplicitCasted(expr) => lhs = expr,
+            ExprTypeCheckResult::Error(diagnostic) => return Err(diagnostic),
+            ExprTypeCheckResult::NotEqualAndCantImplicitCast => {
+                return Err(type_mismatch_error(
+                    tokens[*position - 1].location,
+                    expected_type,
+                    lhs.expr_type(env),
+                )
+                .as_boxed());
+            }
+            _ => {}
         }
 
-        let rhs = parse_logical_and_expression(context, env, tokens, position)?;
-        if rhs.expr_type(env) != DataType::Boolean {
-            return Err(type_mismatch_error(
-                tokens[*position].location,
-                DataType::Boolean,
-                lhs.expr_type(env),
-            )
-            .as_boxed());
+        // Consume operator
+        *position += 1;
+
+        let mut rhs = parse_logical_and_expression(context, env, tokens, position)?;
+        match is_expression_type_equals(env, &rhs, &expected_type) {
+            ExprTypeCheckResult::ImplicitCasted(expr) => rhs = expr,
+            ExprTypeCheckResult::Error(diagnostic) => return Err(diagnostic),
+            ExprTypeCheckResult::NotEqualAndCantImplicitCast => {
+                return Err(type_mismatch_error(
+                    tokens[*position].location,
+                    expected_type,
+                    rhs.expr_type(env),
+                )
+                .as_boxed());
+            }
+            _ => {}
         }
 
         lhs = Box::new(LogicalExpression {
@@ -1174,32 +1280,39 @@ fn parse_logical_and_expression(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
-    let expression = parse_bitwise_or_expression(context, env, tokens, position);
-    if expression.is_err() || *position >= tokens.len() {
-        return expression;
-    }
-
-    let mut lhs = expression.ok().unwrap();
+    let mut lhs = parse_bitwise_or_expression(context, env, tokens, position)?;
     while *position < tokens.len() && tokens[*position].kind == TokenKind::LogicalAnd {
-        *position += 1;
-
-        if lhs.expr_type(env) != DataType::Boolean {
-            return Err(type_mismatch_error(
-                tokens[*position - 2].location,
-                DataType::Boolean,
-                lhs.expr_type(env),
-            )
-            .as_boxed());
+        let expected_type = DataType::Boolean;
+        match is_expression_type_equals(env, &lhs, &expected_type) {
+            ExprTypeCheckResult::ImplicitCasted(expr) => lhs = expr,
+            ExprTypeCheckResult::Error(diagnostic) => return Err(diagnostic),
+            ExprTypeCheckResult::NotEqualAndCantImplicitCast => {
+                return Err(type_mismatch_error(
+                    tokens[*position - 1].location,
+                    expected_type,
+                    lhs.expr_type(env),
+                )
+                .as_boxed());
+            }
+            _ => {}
         }
 
-        let rhs = parse_bitwise_or_expression(context, env, tokens, position)?;
-        if rhs.expr_type(env) != DataType::Boolean {
-            return Err(type_mismatch_error(
-                tokens[*position].location,
-                DataType::Boolean,
-                lhs.expr_type(env),
-            )
-            .as_boxed());
+        // Consume operator
+        *position += 1;
+
+        let mut rhs = parse_bitwise_or_expression(context, env, tokens, position)?;
+        match is_expression_type_equals(env, &rhs, &expected_type) {
+            ExprTypeCheckResult::ImplicitCasted(expr) => rhs = expr,
+            ExprTypeCheckResult::Error(diagnostic) => return Err(diagnostic),
+            ExprTypeCheckResult::NotEqualAndCantImplicitCast => {
+                return Err(type_mismatch_error(
+                    tokens[*position].location,
+                    expected_type,
+                    rhs.expr_type(env),
+                )
+                .as_boxed());
+            }
+            _ => {}
         }
 
         lhs = Box::new(LogicalExpression {
@@ -1218,29 +1331,24 @@ fn parse_bitwise_or_expression(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
-    let expression = parse_logical_xor_expression(context, env, tokens, position);
-    if expression.is_err() || *position >= tokens.len() {
-        return expression;
-    }
-
-    let lhs = expression.ok().unwrap();
-    if tokens[*position].kind == TokenKind::BitwiseOr {
+    let lhs = parse_logical_xor_expression(context, env, tokens, position)?;
+    if *position < tokens.len() && tokens[*position].kind == TokenKind::BitwiseOr {
         *position += 1;
 
-        if lhs.expr_type(env) != DataType::Boolean {
+        if lhs.expr_type(env) != DataType::Integer {
             return Err(type_mismatch_error(
                 tokens[*position - 2].location,
-                DataType::Boolean,
+                DataType::Integer,
                 lhs.expr_type(env),
             )
             .as_boxed());
         }
 
         let rhs = parse_logical_xor_expression(context, env, tokens, position)?;
-        if rhs.expr_type(env) != DataType::Boolean {
+        if rhs.expr_type(env) != DataType::Integer {
             return Err(type_mismatch_error(
                 tokens[*position].location,
-                DataType::Boolean,
+                DataType::Integer,
                 lhs.expr_type(env),
             )
             .as_boxed());
@@ -1262,30 +1370,39 @@ fn parse_logical_xor_expression(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
-    let expression = parse_bitwise_and_expression(context, env, tokens, position);
-    if expression.is_err() || *position >= tokens.len() {
-        return expression;
-    }
-
-    let mut lhs = expression.ok().unwrap();
+    let mut lhs = parse_bitwise_and_expression(context, env, tokens, position)?;
     while *position < tokens.len() && tokens[*position].kind == TokenKind::LogicalXor {
-        *position += 1;
-
-        if lhs.expr_type(env) != DataType::Boolean {
-            return Err(type_mismatch_error(
-                tokens[*position - 2].location,
-                DataType::Boolean,
-                lhs.expr_type(env),
-            ));
+        let expected_type = DataType::Boolean;
+        match is_expression_type_equals(env, &lhs, &expected_type) {
+            ExprTypeCheckResult::ImplicitCasted(expr) => lhs = expr,
+            ExprTypeCheckResult::Error(diagnostic) => return Err(diagnostic),
+            ExprTypeCheckResult::NotEqualAndCantImplicitCast => {
+                return Err(type_mismatch_error(
+                    tokens[*position - 1].location,
+                    expected_type,
+                    lhs.expr_type(env),
+                )
+                .as_boxed());
+            }
+            _ => {}
         }
 
-        let rhs = parse_bitwise_and_expression(context, env, tokens, position)?;
-        if rhs.expr_type(env) != DataType::Boolean {
-            return Err(type_mismatch_error(
-                tokens[*position].location,
-                DataType::Boolean,
-                lhs.expr_type(env),
-            ));
+        // Consume operator
+        *position += 1;
+
+        let mut rhs = parse_bitwise_and_expression(context, env, tokens, position)?;
+        match is_expression_type_equals(env, &rhs, &expected_type) {
+            ExprTypeCheckResult::ImplicitCasted(expr) => rhs = expr,
+            ExprTypeCheckResult::Error(diagnostic) => return Err(diagnostic),
+            ExprTypeCheckResult::NotEqualAndCantImplicitCast => {
+                return Err(type_mismatch_error(
+                    tokens[*position].location,
+                    expected_type,
+                    rhs.expr_type(env),
+                )
+                .as_boxed());
+            }
+            _ => {}
         }
 
         lhs = Box::new(LogicalExpression {
@@ -1304,28 +1421,23 @@ fn parse_bitwise_and_expression(
     tokens: &[Token],
     position: &mut usize,
 ) -> Result<Box<dyn Expression>, Box<Diagnostic>> {
-    let expression = parse_equality_expression(context, env, tokens, position);
-    if expression.is_err() || *position >= tokens.len() {
-        return expression;
-    }
-
-    let mut lhs = expression.ok().unwrap();
+    let mut lhs = parse_equality_expression(context, env, tokens, position)?;
     if *position < tokens.len() && tokens[*position].kind == TokenKind::BitwiseAnd {
         *position += 1;
 
-        if lhs.expr_type(env) != DataType::Boolean {
+        if lhs.expr_type(env) != DataType::Integer {
             return Err(type_mismatch_error(
                 tokens[*position - 2].location,
-                DataType::Boolean,
+                DataType::Integer,
                 lhs.expr_type(env),
             ));
         }
 
         let rhs = parse_equality_expression(context, env, tokens, position)?;
-        if rhs.expr_type(env) != DataType::Boolean {
+        if rhs.expr_type(env) != DataType::Integer {
             return Err(type_mismatch_error(
                 tokens[*position].location,
-                DataType::Boolean,
+                DataType::Integer,
                 lhs.expr_type(env),
             ));
         }
@@ -1428,7 +1540,6 @@ fn parse_comparison_expression(
         };
 
         let mut rhs = parse_bitwise_shift_expression(context, env, tokens, position)?;
-
         match are_types_equals(env, &lhs, &rhs) {
             TypeCheckResult::Equals => {}
             TypeCheckResult::RightSideCasted(expr) => rhs = expr,
@@ -1740,6 +1851,14 @@ fn parse_index_or_slice_expression(
             // Consume Colon `:`
             *position += 1;
 
+            // In case the user use default slice start and end, we can ignore the slice expression
+            // and return array or any kind of expression value directly
+            if *position < tokens.len() && tokens[*position].kind == TokenKind::RightBracket {
+                // Consume right bracket `]`
+                *position += 1;
+                return Ok(expression);
+            }
+
             let slice_end = parse_unary_expression(context, env, tokens, position)?;
             let end_type = slice_end.expr_type(env);
             if !end_type.is_int() {
@@ -2008,10 +2127,8 @@ fn parse_arguments_expressions(
 
         while *position < tokens.len() && tokens[*position].kind != TokenKind::RightParen {
             let argument = parse_expression(context, env, tokens, position)?;
-            let argument_literal = get_expression_name(&argument);
-            if argument_literal.is_ok() {
-                let literal = argument_literal.ok().unwrap();
-                context.hidden_selections.push(literal);
+            if let Some(argument_literal) = expression_literal(&argument) {
+                context.hidden_selections.push(argument_literal);
             }
 
             arguments.push(argument);
@@ -2488,20 +2605,13 @@ fn un_expected_content_after_correct_statement(
         .as_boxed()
 }
 
+#[inline(always)]
 #[allow(clippy::borrowed_box)]
-fn get_expression_name(expression: &Box<dyn Expression>) -> Result<String, ()> {
+fn expression_literal(expression: &Box<dyn Expression>) -> Option<String> {
     if let Some(symbol) = expression.as_any().downcast_ref::<SymbolExpression>() {
-        return Ok(symbol.value.to_string());
+        return Some(symbol.value.to_string());
     }
-
-    if let Some(variable) = expression
-        .as_any()
-        .downcast_ref::<GlobalVariableExpression>()
-    {
-        return Ok(variable.name.to_string());
-    }
-
-    Err(())
+    None
 }
 
 #[inline(always)]
