@@ -14,6 +14,7 @@ pub enum TokenKind {
     By,
     In,
     Is,
+    On,
     Not,
     Like,
     Glob,
@@ -1075,6 +1076,7 @@ fn resolve_symbol_kind(literal: String) -> TokenKind {
         "between" => TokenKind::Between,
         "in" => TokenKind::In,
         "is" => TokenKind::Is,
+        "on" => TokenKind::On,
         "not" => TokenKind::Not,
         "like" => TokenKind::Like,
         "glob" => TokenKind::Glob,
