@@ -240,15 +240,23 @@ fn select_commits(
                 continue;
             }
 
-            if field_name == "name" {
-                let name = commit.author().name.to_string();
-                values.push(Value::Text(name));
+            if field_name == "author_name" {
+                values.push(Value::Text(commit.author().name.to_string()));
                 continue;
             }
 
-            if field_name == "email" {
-                let email = commit.author().email.to_string();
-                values.push(Value::Text(email));
+            if field_name == "author_email" {
+                values.push(Value::Text(commit.author().email.to_string()));
+                continue;
+            }
+
+            if field_name == "committer_name" {
+                values.push(Value::Text(commit.committer().name.to_string()));
+                continue;
+            }
+
+            if field_name == "committer_email" {
+                values.push(Value::Text(commit.committer().email.to_string()));
                 continue;
             }
 
@@ -272,6 +280,11 @@ fn select_commits(
                 continue;
             }
 
+            if field_name == "parents_count" {
+                values.push(Value::Integer(commit.parents.len() as i64));
+                continue;
+            }
+
             if field_name == "repo" {
                 values.push(Value::Text(repo_path.to_string()));
                 continue;
