@@ -10,6 +10,10 @@ pub fn tables_fields_types() -> &'static HashMap<&'static str, DataType> {
         map.insert("title", DataType::Text);
         map.insert("message", DataType::Text);
         map.insert("name", DataType::Text);
+        map.insert("author_name", DataType::Text);
+        map.insert("author_email", DataType::Text);
+        map.insert("committer_name", DataType::Text);
+        map.insert("committer_email", DataType::Text);
         map.insert("full_name", DataType::Text);
         map.insert("insertions", DataType::Integer);
         map.insert("deletions", DataType::Integer);
@@ -20,6 +24,7 @@ pub fn tables_fields_types() -> &'static HashMap<&'static str, DataType> {
         map.insert("is_head", DataType::Boolean);
         map.insert("is_remote", DataType::Boolean);
         map.insert("commit_count", DataType::Integer);
+        map.insert("parents_count", DataType::Integer);
         map.insert("updated", DataType::DateTime);
         map.insert("repo", DataType::Text);
         map
@@ -37,9 +42,12 @@ pub fn tables_fields_names() -> &'static HashMap<&'static str, Vec<&'static str>
                 "commit_id",
                 "title",
                 "message",
-                "name",
-                "email",
+                "author_name",
+                "author_email",
+                "committer_name",
+                "committer_email",
                 "datetime",
+                "parents_count",
                 "repo",
             ],
         );
